==> virtu-crud-1.1.2.tgz: package/test/test-index.js <==
// Author: Jean-Philippe Beaudet @ S3R3NITY Technology 
//
// Virtuba crud router tests
// CRUD
//
// Version : 0.0.1s
// Copyrigths S3R3NITY Technologies.
//
//========================================================
var chai = require('chai');
var aes256 = require('aes256')
var should = require('chai').should()
var crud = require('../index.js')
var dummy = 1
var config = require("../config.js")
	
var TMP_FILE = config.tmp_file
var PASSPHRASE = config.passphrase

describe('#crud', function() {
	it('add-create;', function() {
		var q = crud.add.create("", crud.toHash("test"))
		var ret = q.actions.create[0]
		ret[0].should.equal("");
		ret[1].should.equal(crud.toHash("test"));
		crud.refresh(function(queue){
		});
	});
	it('add-read;', function() {
		var q = crud.add.read(crud.toHash("test1"))
		var ret = q.actions.read[0]
		ret.should.equal(crud.toHash("test1"));
		crud.refresh(function(queue){
		});
	});
	it('add-update;', function() {
		var q = crud.add.update(crud.toHash("test1"), crud.toHash("test2"))
		var ret = q.actions.update[0]
		ret[0].should.equal(crud.toHash("test1"));
		ret[1].should.equal(crud.toHash("test2"));
		crud.refresh(function(queue){
		});
	});
	it('add-destroy;', function() {
		var q = crud.add.destroy(crud.toHash("test3"))
		var ret = q.actions.destroy[0]
		ret.should.equal(crud.toHash("test3"));
		crud.refresh(function(queue){
		});
	});
	it('refresh;', function() {
		var q = crud.add.read(crud.toHash("test1"))
		var ret = q.actions.read[0]
		ret.should.equal(crud.toHash("test1"))
		q.actions.read.length.should.equal(1)
		var c = crud.refresh(function(queue){
			queue.actions.read.length.should.equal(0);
			})
	});
});
describe('#send', function() {
	it('compile value && writejson;', function() {
		var key = PASSPHRASE;
		var encrypted = aes256.encrypt(key, '{map:"map"}');
		var q = crud.add.create("", crud.toHash("test"))
		crud.send(crud.toHash("name"), encrypted , function(err){
			var myObj = require('./'+crud.toHash("name")+'.json')
			options = {
				message: openpgp.message.readArmored(encrypted),     // parse armored message

			};
			openpgp.decrypt(options).then(function(plaintext) {
				var decrypted = JSON.parse(plaintext.data); // 'Hello, World!'
				//var decrypted = aes256.decrypt(key, myObj);
				(decrypted.username_hash).should.equal(crud.toHash("name"));
				(decrypted.actions.create[0]).should.equal(["", crud.toHash("test")]);
			});
		})
	});
});

==> virtu-crud-1.1.5.tgz: package/test/test-index.js <==
// Author: Jean-Philippe Beaudet @ S3R3NITY Technology 
//
// Virtuba crud router tests
// CRUD
//
// Version : 0.0.1s
// Copyrigths S3R3NITY Technologies.
//
//========================================================
var chai = require('chai');
var aes256 = require('aes256')
var should = require('chai').should()
var crud = require('../index.js')
var dummy = 1
var config = require("../config.js")
	
var TMP_FILE = config.tmp_file
var PASSPHRASE = config.passphrase

describe('#crud', function() {
	it('add-create;', function() {
		var q = crud.add.create("", crud.toHash("test"))
		var ret = q.actions.create[0]
		ret[0].should.equal("");
		ret[1].should.equal(crud.toHash("test"));
		crud.refresh(function(queue){
		});
	});
	it('add-read;', function() {
		var q = crud.add.read(crud.toHash("test1"))
		var ret = q.actions.read[0]
		ret.should.equal(crud.toHash("test1"));
		crud.refresh(function(queue){
		});
	});
	it('add-update;', function() {
		var q = crud.add.update(crud.toHash("test1"), crud.toHash("test2"))
		var ret = q.actions.update[0]
		ret[0].should.equal(crud.toHash("test1"));
		ret[1].should.equal(crud.toHash("test2"));
		crud.refresh(function(queue){
		});
	});
	it('add-destroy;', function() {
		var q = crud.add.destroy(crud.toHash("test3"))
		var ret = q.actions.destroy[0]
		ret.should.equal(crud.toHash("test3"));
		crud.refresh(function(queue){
		});
	});
	it('refresh;', function() {
		var q = crud.add.read(crud.toHash("test1"))
		var ret = q.actions.read[0]
		ret.should.equal(crud.toHash("test1"))
		q.actions.read.length.should.equal(1)
		var c = crud.refresh(function(queue){
			queue.actions.read.length.should.equal(0);
			})
	});
});

describe('#send', function() {
	it('compile value && writejson;', function() {
		var key = PASSPHRASE;
		var encrypted = aes256.encrypt(key, '{map:"map"}');
		var q = crud.add.create("", crud.toHash("test"))
		console.log("ho")
		crud.send(crud.toHash("name"), encrypted , function(err){
			console.log("yay")
			//var myObj = require('./'+crud.toHash("name")+'.json')
			//options = {
			//	message: openpgp.message.readArmored(encrypted),     // parse armored message

			//};
			//openpgp.decrypt(options).then(function(plaintext) {
				//var decrypted = JSON.parse(plaintext.data); // 'Hello, World!'
				//var decrypted = aes256.decrypt(key, myObj);
				//(decrypted.username_hash).should.equal(crud.toHash("name"));
				//(decrypted.actions.create[0]).should.equal(["", crud.toHash("test")]);
			//});
			
			//(true).should.equal(true)
			
		})
	});
});
